# Discovering AI Agents from Google Agent Engine
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine#overview)
  * [Scope](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine#scope)
  * [Limitations](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine#limitations)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine#prerequisites)
  * [Step 1: Create a Service Account in the Google Cloud Console](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine#step-1:-create-a-service-account-in-the-google-cloud-console)
  * [Step 2: Generate and Download a JSON Key](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine#step-2:-generate-and-download-a-json-key)
  * [Step 3: Connect SAP LeanIX to Google Agent Engine](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine#step-3:-connect-sap-leanix-to-google-agent-engine)
  * [Linking Discovered Items to Fact Sheets](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine#linking-discovered-items-to-fact-sheets)
  * [Viewing Synchronization Logs](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine#viewing-synchronization-logs)


Learn how to integrate SAP LeanIX with Google Agent Engine to automate the discovery of AI agents.
